%Network Data GUI Program
%Amod U, Oct. 2008

% Three bus system
% Base MVA and Voltage Data

Sbase = 100*10^06;

Vbase1_LL = 22*10^03;
Vbase2_LL = 345*10^03;

Vbase1_LN = Vbase1_LL/sqrt(3);
Vbase2_LN = Vbase2_LL/sqrt(3);

%Calculation of Ibase and Zbase

Ibase1 = (1/sqrt(3))*Sbase/Vbase1_LL;
Ibase2 = (1/sqrt(3))*Sbase/Vbase2_LL;

Zbase1 = (Vbase1_LL^2)/Sbase;
Zbase2 = (Vbase2_LL^2)/Sbase;

fprintf( ' %s  %8.0f  \n','Sbase = ',Sbase)
fprintf( ' %s  %8.3f  \n','Vbase1_LL = ',Vbase1_LL)
fprintf( ' %s  %8.3f  \n','Vbase2_LL = ',Vbase2_LL)
fprintf( ' %s  %8.3f  \n','Vbase1_LN = ',Vbase1_LN)
fprintf( ' %s  %8.3f  \n','Vbase2_LN = ',Vbase2_LN)
fprintf( ' %s  %8.3f  \n','Ibase1 = ',Ibase1)
fprintf( ' %s  %8.3f  \n','Ibase2 = ',Ibase2)
fprintf( ' %s  %8.3f  \n','Zbase1 = ',Zbase1)
fprintf( ' %s  %8.3f  \n','Zbase2 = ',Zbase2)


% Transformer types
% 0 = line (not a transformer)
% 1 = Y-Y grounded neutral on both sides
% 2 = Y-D grounded neutral on Y side
% 3 = generator internal impedance

%*******************************************************
%    Select the Fault Type
%*******************************************************

name1='Fault Type Selection Dialog';
prompt1={'SELECT FAULT'};
list1 ={
    'Three Phase Fault';
	'Single Line to Ground Fault';
      };

fault_type=listdlg('promptstring',prompt1,...
   'liststring',list1,...
   'Selectionmode','single',...
   'name',name1,...
   'listsize',[200,100]);

faulttype = list1(fault_type);
faulttype = char(faulttype);

switch faulttype
    case 'Three Phase Fault'
%********************************************************
% Three Phase to Ground Fault
%********************************************************

%********************************************************
% Select the Fault Location (Bus or Line)
%********************************************************
        
name2='Fault Location Selection Dialog';
prompt2={'SELECT FAULT LOCATION'};
list2 ={
    'Bus Fault';
	'Line Fault';
       };

faultloc=listdlg('promptstring',prompt2,...
   'liststring',list2,...
   'Selectionmode','single',...
   'name',name2,...
   'listsize',[200,100]);

%********************************************************
% Select the bus at which fault occurs
%********************************************************

   if faultloc==1     
        name3='Fault Bus Selection Dialog';
prompt3={'SELECT FAULT BUS'};
list3 ={
    'Bus 1';
	'Bus 2';
    'Bus 3';
      };

faultbus=listdlg('promptstring',prompt3,...
   'liststring',list3,...
   'Selectionmode','single',...
   'name',name3,...
   'listsize',[200,100]);

numbuses=7;

  % Network Data for Three Phase Bus Fault
    
    % from      to    r1          x1          r0         	x0    TransformerCode
linedata=[
1	        2	0.01	    0.08	    0.01	        0.08	    0	%1	Trans Line 1 - 2
1           3   0.005	    0.044	    0.005	        0.044       0   %2  Trans Line 1 - 3
2	        3	0.0025	    0.022	    0.0025	        0.022       0   %3  Trans Line 2 - 3
4           1	0	        0.25	    0	            0.25	    2	%4	Delta-Y 22kV to 345 kV transformer
5           4   0	        0.25	    0	            0.25	    3   %5  Generator internal impedance y'  
6           2	0	        0.25	    0	            0.25	    1	%6	Y-Y 22kV to 345 kV transformer
7           6   0	        0.25	    0	            0.25	    3   %7  Generator internal impedance y'  
];

% Number of buses for three-phase fault

% bustype: 1 = generator, 2 = load, 3 = reference bus, 0 = transfer bus
bustype = [ 1
            1
            2
            0
            3
            0
            3 ];

busname = [
'Genbus 1         ' %1   
'Genbus 2         ' %2
'Load bus 3       ' %3
'Gen 1 terminal   ' %4
'Gen 1 internal   ' %5
'Gen 2 terminal   ' %6
'Gen 2 internal   ' %7
];

branchname = [
'Trans Line 1 - 2                           ' %1
'Trans Line 1 - 3                           ' %2
'Trans Line 2 - 3                           ' %3
'Y-Delta 22kV to 345 kV transformer 4 - 1   ' %4
'Generator internal impedance y-prime 5 - 4 ' %5
'Y-Y 22kV to 345 kV transformer 6 - 2       ' %6
'Generator internal impedance y-prime 7 - 6 ' %7
];
   else
%********************************************************
% Select the Line at which fault occurs and
% the percentage of line length at which it occurs.
% Percent of line length is chosen with reference to lower bus number.
%********************************************************

name3='Fault Line Selection Dialog';
prompt3={'SELECT THE FAULT LINE'};
list3 ={
    'Line 1-2';
	'Line 1-3';
    'Line 2-3';
      };

fault_line=listdlg('promptstring',prompt3,...
   'liststring',list3,...
   'Selectionmode','single',...
   'name',name3,...
   'listsize',[200,100]);

 prompt={'Enter the Percentage (Except 0 and 100) of the line length at which SLG Fault Occurs (From Low Bus Number to High Bus Number):'};
   name='Percentage of the transmission line length';
   numlines=1;
   defaultanswer={'40'};
   x1=inputdlg(prompt,name,numlines,defaultanswer);
   x1=cell2mat(x1);
   x1=str2num(x1);
   x=x1/100;
   numbuses=8;
   faultbus=8;
     if fault_line==1       %For 3-phase fault between bus 1-2
        
% from      to    r1          x1          r0         	x0    TransformerCode
linedata=[
1	        8	0.01*x	    0.08*x	    0.01*x	        0.08*x	    0	%1	Trans Line 1 - 2 fault at x% of line
8	        2	0.01*(1-x)  0.08*(1-x)  0.01*(1-x)      0.08*(1-x)  0	%1	Trans Line 1 - 2 fault at x% of line
1           3   0.005	    0.044	    0.005	        0.044       0   %2  Trans Line 1 - 3
2	        3	0.0025	    0.022	    0.0025	        0.022       0   %3  Trans Line 2 - 3
4           1	0	        0.25	    0	            0.25	    2	%4	Delta-Y 22kV to 345 kV transformer
5           4   0	        0.25	    0	            0.25	    3   %5  Generator internal impedance y'  
6           2	0	        0.25	    0	            0.25	    1	%6	Y-Y 22kV to 345 kV transformer
7           6   0	        0.25	    0	            0.25	    3   %7  Generator internal impedance y'  
];

    elseif fault_line==2   %For 3-phase fault between bus 1-3
        
% from      to    r1          x1          r0         	x0    TransformerCode
linedata=[
1	        2	0.01	    0.08	    0.01	        0.08	    0	%1	Trans Line 1 - 2 fault at x% of line
1	        8	0.005*x     0.044*x     0.005*x         0.044*x     0	%1	Trans Line 1 - 2 fault at x% of line
8           3   0.005*(1-x) 0.044*(1-x) 0.005*(1-x)	    0.044*(1-x) 0   %2  Trans Line 1 - 3
2	        3	0.0025	    0.022	    0.0025	        0.022       0   %3  Trans Line 2 - 3
4           1	0	        0.25	    0	            0.25	    2	%4	Delta-Y 22kV to 345 kV transformer
5           4   0	        0.25	    0	            0.25	    3   %5  Generator internal impedance y'  
6           2	0	        0.25	    0	            0.25	    1	%6	Y-Y 22kV to 345 kV transformer
7           6   0	        0.25	    0	            0.25	    3   %7  Generator internal impedance y'  
];

     else                  %For 3-phase fault between bus 2-3
        
        % from      to       r1          x1          r0         	x0    TransformerCode
linedata=[
1	        2	0.01	     0.08	     0.01	        0.08	    0	%1	Trans Line 1 - 2 fault at x% of line
1           3   0.005	     0.044	     0.005	        0.044       0	%1	Trans Line 1 - 2 fault at x% of line
2	        8	0.0025*x	 0.022*x     0.0025*x	    0.022*x     0   %2  Trans Line 1 - 3
8	        3	0.0025*(1-x) 0.022*(1-x) 0.0025*(1-x)   0.022*(1-x) 0   %3  Trans Line 2 - 3
4           1	0	         0.25	     0	            0.25	    2	%4	Delta-Y 22kV to 345 kV transformer
5           4   0	         0.25	     0	            0.25	    3   %5  Generator internal impedance y'  
6           2	0	         0.25	     0	            0.25	    1	%6	Y-Y 22kV to 345 kV transformer
7           6   0	         0.25	     0	            0.25	    3   %7  Generator internal impedance y'  
];
     end

% Number of buses for 3-phase to ground Line Fault is 8.
% bustype: 1 = generator, 2 = load, 3 = reference bus, 0 = transfer bus
bustype = [ 1
            1
            2
            0
            3
            0
            3
            0 ]; % changed with line fault

busname = [
'Genbus 1         ' %1   
'Genbus 2         ' %2
'Load bus 3       ' %3
'Gen 1 terminal   ' %4
'Gen 1 internal   ' %5
'Gen 2 terminal   ' %6
'Gen 2 internal   ' %7
'Fault            ' %8  % changed with line fault
];
if fault_line==1
branchname = [
'Trans Line 1 - 8  first segment            ' %1
'Trans Line 8 - 2  second segment           ' %1
'Trans Line 1 - 3                           ' %2
'Trans Line 2 - 3                           ' %3
'Y-Delta 22kV to 345 kV transformer 4 - 1   ' %4
'Generator internal impedance y-prime 5 - 4 ' %5
'Y-Y 22kV to 345 kV transformer 6 - 2       ' %6
'Generator internal impedance y-prime 7 - 6 ' %7
];
elseif fault_line==2
branchname = [
'Trans Line 1 - 2                           ' %1
'Trans Line 1 - 8  first segment            ' %1
'Trans Line 8 - 3  second segment           ' %2
'Trans Line 2 - 3                           ' %3
'Y-Delta 22kV to 345 kV transformer 4 - 1   ' %4
'Generator internal impedance y-prime 5 - 4 ' %5
'Y-Y 22kV to 345 kV transformer 6 - 2       ' %6
'Generator internal impedance y-prime 7 - 6 ' %7
];
else
branchname = [
'Trans Line 1 - 2                           ' %1
'Trans Line 1 - 3                           ' %1
'Trans Line 2 - 8  first segment            ' %2
'Trans Line 8 - 3  second segment           ' %3
'Y-Delta 22kV to 345 kV transformer 4 - 1   ' %4
'Generator internal impedance y-prime 5 - 4 ' %5
'Y-Y 22kV to 345 kV transformer 6 - 2       ' %6
'Generator internal impedance y-prime 7 - 6 ' %7
];
end
   end

%********************************************************
% Single Phase To Ground Fault
%********************************************************

 case 'Single Line to Ground Fault'
        name2='Fault Location Selection Dialog';
prompt2={'SELECT FAULT LOCATION'};
list2 ={
    'Bus Fault';
	'Line Fault';
       };
   
%********************************************************
% Select the Fault Location (Bus or Line)
%********************************************************

faultloc=listdlg('promptstring',prompt2,...
   'liststring',list2,...
   'Selectionmode','single',...
   'name',name2,...
   'listsize',[200,100]);
        
   if faultloc==1     
        name3='Fault Bus Selection Dialog';
prompt3={'SELECT FAULT BUS'};
list3 ={
    'Bus 1';
	'Bus 2';
    'Bus 3';
      };

%********************************************************
% Select the bus at which fault occurs
%********************************************************

  faultbus=listdlg('promptstring',prompt3,...
   'liststring',list3,...
   'Selectionmode','single',...
   'name',name3,...
   'listsize',[200,100]);

numbuses=7;

  % Network Data for Single Phase to Ground Bus Fault
    
    % from      to    r1          x1          r0         	x0    TransformerCode
linedata=[
1	        2	0.01	    0.08	    0.01	        0.08	    0	%1	Trans Line 1 - 2
1           3   0.005	    0.044	    0.005	        0.044       0   %2  Trans Line 1 - 3
2	        3	0.0025	    0.022	    0.0025	        0.022       0   %3  Trans Line 2 - 3
4           1	0	        0.25	    0	            0.25	    2	%4	Delta-Y 22kV to 345 kV transformer
5           4   0	        0.25	    0	            0.25	    3   %5  Generator internal impedance y'  
6           2	0	        0.25	    0	            0.25	    1	%6	Y-Y 22kV to 345 kV transformer
7           6   0	        0.25	    0	            0.25	    3   %7  Generator internal impedance y'  
];

% Number of buses for Single-Phase to Ground Bus fault

% bustype: 1 = generator, 2 = load, 3 = reference bus, 0 = transfer bus
bustype = [ 1
            1
            2
            0
            3
            0
            3 ];

busname = [
'Genbus 1         ' %1   
'Genbus 2         ' %2
'Load bus 3       ' %3
'Gen 1 terminal   ' %4
'Gen 1 internal   ' %5
'Gen 2 terminal   ' %6
'Gen 2 internal   ' %7
];

branchname = [
'Trans Line 1 - 2                           ' %1
'Trans Line 1 - 3                           ' %2
'Trans Line 2 - 3                           ' %3
'Y-Delta 22kV to 345 kV transformer 4 - 1   ' %4
'Generator internal impedance y-prime 5 - 4 ' %5
'Y-Y 22kV to 345 kV transformer 6 - 2       ' %6
'Generator internal impedance y-prime 7 - 6 ' %7
];
   else       
name2='Fault Line Selection Dialog';
prompt2={'SELECT THE FAULT LINE'};
list2 ={
    'Line 1-2';
	'Line 1-3';
    'Line 2-3';
      };

fault_line=listdlg('promptstring',prompt2,...
   'liststring',list2,...
   'Selectionmode','single',...
   'name',name2,...
   'listsize',[200,100]);

 prompt={'Enter the Percentage of the line length at which SLG Fault Occurs (From Low Bus Number to High Bus Number):'};
   name='Percentage of the transmission line length (Except 0 and 100)';
   numlines=1;
   defaultanswer={'40'};
   x1=inputdlg(prompt,name,numlines,defaultanswer);
   x1=cell2mat(x1);
   x1=str2num(x1);
   x=x1/100;
   numbuses=8;
   faultbus=8;
     if fault_line==1       %For SLG fault between bus 1-2
        
% from      to    r1          x1          r0         	x0    TransformerCode
linedata=[
1	        8	0.01*x	    0.08*x	    0.01*x	        0.08*x	    0	%1	Trans Line 1 - 2 fault at x% of line
8	        2	0.01*(1-x)  0.08*(1-x)  0.01*(1-x)      0.08*(1-x)  0	%1	Trans Line 1 - 2 fault at x% of line
1           3   0.005	    0.044	    0.005	        0.044       0   %2  Trans Line 1 - 3
2	        3	0.0025	    0.022	    0.0025	        0.022       0   %3  Trans Line 2 - 3
4           1	0	        0.25	    0	            0.25	    2	%4	Delta-Y 22kV to 345 kV transformer
5           4   0	        0.25	    0	            0.25	    3   %5  Generator internal impedance y'  
6           2	0	        0.25	    0	            0.25	    1	%6	Y-Y 22kV to 345 kV transformer
7           6   0	        0.25	    0	            0.25	    3   %7  Generator internal impedance y'  
];

    elseif fault_line==2   %For SLG fault between bus 1-3
        
% from      to    r1          x1          r0         	x0    TransformerCode
linedata=[
1	        2	0.01	    0.08	    0.01	        0.08	    0	%1	Trans Line 1 - 2 fault at x% of line
1	        8	0.005*x     0.044*x     0.005*x         0.044*x     0	%1	Trans Line 1 - 2 fault at x% of line
8           3   0.005*(1-x) 0.044*(1-x) 0.005*(1-x)	    0.044*(1-x) 0   %2  Trans Line 1 - 3
2	        3	0.0025	    0.022	    0.0025	        0.022       0   %3  Trans Line 2 - 3
4           1	0	        0.25	    0	            0.25	    2	%4	Delta-Y 22kV to 345 kV transformer
5           4   0	        0.25	    0	            0.25	    3   %5  Generator internal impedance y'  
6           2	0	        0.25	    0	            0.25	    1	%6	Y-Y 22kV to 345 kV transformer
7           6   0	        0.25	    0	            0.25	    3   %7  Generator internal impedance y'  
];

     else                  %For SLG fault between bus 2-3
        
        % from      to       r1          x1          r0         	x0    TransformerCode
linedata=[
1	        2	0.01	     0.08	     0.01	        0.08	    0	%1	Trans Line 1 - 2 fault at x% of line
1           3   0.005	     0.044	     0.005	        0.044       0	%1	Trans Line 1 - 2 fault at x% of line
2	        8	0.0025*x	 0.022*x     0.0025*x	    0.022*x     0   %2  Trans Line 1 - 3
8	        3	0.0025*(1-x) 0.022*(1-x) 0.0025*(1-x)   0.022*(1-x) 0   %3  Trans Line 2 - 3
4           1	0	         0.25	     0	            0.25	    2	%4	Delta-Y 22kV to 345 kV transformer
5           4   0	         0.25	     0	            0.25	    3   %5  Generator internal impedance y'  
6           2	0	         0.25	     0	            0.25	    1	%6	Y-Y 22kV to 345 kV transformer
7           6   0	         0.25	     0	            0.25	    3   %7  Generator internal impedance y'  
];
     end

% Number of buses for SLG Fault is 8.
% bustype: 1 = generator, 2 = load, 3 = reference bus, 0 = transfer bus
bustype = [ 1
            1
            2
            0
            3
            0
            3
            0 ]; % changed with line fault

busname = [
'Genbus 1         ' %1   
'Genbus 2         ' %2
'Load bus 3       ' %3
'Gen 1 terminal   ' %4
'Gen 1 internal   ' %5
'Gen 2 terminal   ' %6
'Gen 2 internal   ' %7
'Fault            ' %8  % changed with line fault
];
if fault_line==1
branchname = [
'Trans Line 1 - 8  first segment            ' %1
'Trans Line 8 - 2  second segment           ' %1
'Trans Line 1 - 3                           ' %2
'Trans Line 2 - 3                           ' %3
'Y-Delta 22kV to 345 kV transformer 4 - 1   ' %4
'Generator internal impedance y-prime 5 - 4 ' %5
'Y-Y 22kV to 345 kV transformer 6 - 2       ' %6
'Generator internal impedance y-prime 7 - 6 ' %7
];
elseif fault_line==2
branchname = [
'Trans Line 1 - 2                           ' %1
'Trans Line 1 - 8  first segment            ' %1
'Trans Line 8 - 3  second segment           ' %2
'Trans Line 2 - 3                           ' %3
'Y-Delta 22kV to 345 kV transformer 4 - 1   ' %4
'Generator internal impedance y-prime 5 - 4 ' %5
'Y-Y 22kV to 345 kV transformer 6 - 2       ' %6
'Generator internal impedance y-prime 7 - 6 ' %7
];
else
branchname = [
'Trans Line 1 - 2                           ' %1
'Trans Line 1 - 3                           ' %1
'Trans Line 2 - 8  first segment            ' %2
'Trans Line 8 - 3  second segment           ' %3
'Y-Delta 22kV to 345 kV transformer 4 - 1   ' %4
'Generator internal impedance y-prime 5 - 4 ' %5
'Y-Y 22kV to 345 kV transformer 6 - 2       ' %6
'Generator internal impedance y-prime 7 - 6 ' %7
];
end

   end
end

[numlines,numcol] = size(linedata);
     
for iline = 1:numlines
    fbus(iline) = linedata(iline,1);
    tbus(iline) = linedata(iline,2);
    r1(iline) = linedata(iline,3);
    x1(iline) = linedata(iline,4);
    r0(iline) = linedata(iline,5);
    x0(iline) = linedata(iline,6);
    trtype(iline) = linedata(iline,7);
end



Zfault = 0.0;