
function [P Q] = runNewtonRaphson(voltage, angle, Psp, Qsp, CAPFLAG)

% ----------- initialize parameters ---------- %
MAX_ITER = 4;
TOL = 0.001;
convFlag = 1;
iter = 1;
deltaAngle = zeros(1,3);
deltaVoltage = zeros(1,3);

% ---------- initialize variables ------------ %

% V = zeros(1,3);
% S = zeros(1,3);

V = zeros(3,1);
S = zeros(3,1);

P = zeros(3,3);
Q = zeros(3,3);

J = zeros(3,3);
[Y Z Zc] = inputBusData(CAPFLAG);      % get conductance and susceptance
G = real(Y);
B = imag(Y);

% ------- begin Newton-Raphson procedure ------- %

while( convFlag==1 && iter < MAX_ITER)

    angle = angle + deltaAngle;
    voltage = voltage + deltaVoltage;

    % ------ Jacobian equations ------------- %

    J(1,1)=voltage(2)*(voltage(1)*(-G(2,1)*sin(angle(2) - angle(1))+ B(2,1)*cos(angle(2) - angle(1))) + voltage(3)*(-G(2,3)*sin(angle(2) - angle(3))+B(2,3)*cos(angle(2)-angle(3))));
    J(1,2)=voltage(2)*(voltage(3)*(G(2,3)*sin(angle(2) - angle(3)) - B(2,3)*cos(angle(2) - angle(3))));
    J(1,3)=voltage(2)*((G(2,3)*cos(angle(2) - angle(3)) + B(2,3)*sin(angle(2) - angle(3))));
    J(2,1)=voltage(3)*(voltage(2)*(G(3,2)*sin(angle(3) - angle(2)) - B(3,2)*cos(angle(3) - angle(2))));
    J(2,2)=voltage(3)*(voltage(1)*(-G(3,1)*sin(angle(3) - angle(1)) + B(3,1)*cos(angle(3) - angle(1))) + voltage(2)*(-G(3,2)*sin(angle(3)-angle(2))+B(3,2)*cos(angle(3)-angle(2))));
    J(2,3)=2*G(3,3)*voltage(3) + voltage(1)*(G(3,1)*cos(angle(3)-angle(1)) + B(3,1)*sin(angle(3) - angle(1))) + voltage(2)*(G(3,2)*cos(angle(3) - angle(2))+B(3,2)*sin(angle(3) - angle(2)));
    J(3,1)=voltage(3)*(voltage(2)*(G(3,2)*cos(angle(3) - angle(2)) - B(3,2)*sin(angle(3) - angle(2))));
    J(3,2)=voltage(3)*(voltage(1)*(G(3,1)*cos(angle(3) - angle(1)) + B(3,1)*sin(angle(3) - angle(1))) + voltage(2)*(G(3,2)*cos(angle(3) - angle(2)) + B(3,2)*sin(angle(3) - angle(2))));
    J(3,3)= -2*B(3,3)*voltage(3) + voltage(1)*(G(3,1)*sin(angle(3) - angle(1)) - B(3,1)*cos(angle(3) - angle(1))) + voltage(2)*(G(3,2)*sin(angle(3) - angle(2)) - B(3,2)*cos(angle(3) - angle(2)));
    
    
%     % ---------Bus Voltages--------%
%     for i = 1:length(V)
%         V(i) = voltage(i)*exp(sqrt(-1)*angle(i));
%     end
%     Iinj=Y*V';                   % injected current
%     for i = 1:length(V)
%         S(i) = V(i)*conj(Iinj(i));
%     end
%     
%     disp('V')
%     disp(V);
%     disp('S')
%     disp(S);
%     disp('Iinj');
%     disp(Iinj);


  % ---------Bus Voltages--------%
    V(1,1)=voltage(1)*exp(sqrt(-1)*angle(1));
    V(2,1)=voltage(2)*exp(sqrt(-1)*angle(2));
    V(3,1)=voltage(3)*exp(sqrt(-1)*angle(3));

    % -------Injected currents into Buses-------%
    Iinj=Y*V;

    %------- P and Q Injected into Buses--------%
    S(1,1)=V(1,1)*conj(Iinj(1));
    S(1,2)=V(2,1)*conj(Iinj(2));
    S(1,3)=V(3,1)*conj(Iinj(3));
   
    % -----Mismatch at PQ and PV buses-------%
    Mismatch(1,1) = Psp(2) - real(S(1,2));
    Mismatch(2,1) = Psp(3) - real(S(1,3));
    Mismatch(3,1) = Qsp(3) - imag(S(1,3));

    % -------calculate new delta values for ANG2, ANG3, and MAG3------&
    delta = inv(J)*Mismatch;
    deltaAngle(2) = delta(1);
    deltaAngle(3) = delta(2);
    deltaVoltage(3) = delta(3);

    % -------Calculate Power Flow on the Transmission Lines-------%

    if(CAPFLAG)
        for i = 1:length(V)
            for j = 1:length(V)
                if(i~=j)
                    P(i,j) = real(V(i,1)*conj(V(i,1) - V(j,1)/Z(i,j)) + V(i,1)/Zc(i,j));
                    Q(i,j) = imag(V(i,1)*conj(V(i,1) - V(j,1)/Z(i,j)) + V(i,1)/Zc(i,j));
                else
                    P(i,j) = real(S(1,i));
                    Q(i,j) = imag(S(1,i));
                end;
            end;
        end;

    else
        for i = 1:length(V)
            for j = 1:length(V)
                if(i~=j)
                    P(i,j) = real(V(i,1)*conj(V(i,1) - V(j,1)/Z(i,j)));
                    Q(i,j) = imag(V(i,1)*conj(V(i,1) - V(j,1)/Z(i,j)));
                else
                    P(i,j) = real(S(1,i));
                    Q(i,j) = imag(S(1,i));
                end;
            end;
        end;
    end;

	displayResults(P,Q,V,iter);


    if max(abs(Mismatch)) > TOL,
        convFlag=1;
    else
        convFlag=0;
    end
    iter = iter + 1;
end

return;


