
function [P Q] = runNewtonRaphson(voltage, angle, Psp, Qsp, CAPFLAG)

% ----------- initialize parameters ---------- %
MAX_ITER = 20;
TOL = 0.0001;
convFlag = 1;
iter = 1;
deltaAngle = zeros(1,3);
deltaVoltage = zeros(1,3);

% ---------- initialize variables ------------ %

V = zeros(1,3);
S = zeros(1,3);

P = cell(1,MAX_ITER);
Q = cell(1,MAX_ITER);
for i = 1:length(P)
    P{i} = zeros(3,3);
    Q{i} = zeros(3,3);
end

J = zeros(3,3);
[Y Z Zc] = inputBusData(CAPFLAG);      % get conductance and susceptance
G = real(Y);
B = imag(Y);

% ------- begin Newton-Raphson procedure ------- %

while( convFlag==1 && iter < MAX_ITER)

    angle = angle + deltaAngle;
    voltage = voltage + deltaVoltage;

    % ------ Jacobian equations ------------- %

    J(1,1)=voltage(2)*(voltage(1)*(-G(2,1)*sin(angle(2) - angle(1))+ B(2,1)*cos(angle(2) - angle(1))) + voltage(3)*(-G(2,3)*sin(angle(2) - angle(3))+B(2,3)*cos(angle(2)-angle(3))));
    J(1,2)=voltage(2)*(voltage(3)*(G(2,3)*sin(angle(2) - angle(3)) - B(2,3)*cos(angle(2) - angle(3))));
    J(1,3)=voltage(2)*((G(2,3)*cos(angle(2) - angle(3)) + B(2,3)*sin(angle(2) - angle(3))));
    J(2,1)=voltage(3)*(voltage(2)*(G(3,2)*sin(angle(3) - angle(2)) - B(3,2)*cos(angle(3) - angle(2))));
    J(2,2)=voltage(3)*(voltage(1)*(-G(3,1)*sin(angle(3) - angle(1)) + B(3,1)*cos(angle(3) - angle(1))) + voltage(2)*(-G(3,2)*sin(angle(3)-angle(2))+B(3,2)*cos(angle(3)-angle(2))));
    J(2,3)=2*G(3,3)*voltage(3) + voltage(1)*(G(3,1)*cos(angle(3)-angle(1)) + B(3,1)*sin(angle(3) - angle(1))) + voltage(2)*(G(3,2)*cos(angle(3) - angle(2))+B(3,2)*sin(angle(3) - angle(2)));
    J(3,1)=voltage(3)*(voltage(2)*(G(3,2)*cos(angle(3) - angle(2)) - B(3,2)*sin(angle(3) - angle(2))));
    J(3,2)=voltage(3)*(voltage(1)*(G(3,1)*cos(angle(3) - angle(1)) + B(3,1)*sin(angle(3) - angle(1))) + voltage(2)*(G(3,2)*cos(angle(3) - angle(2)) + B(3,2)*sin(angle(3) - angle(2))));
    J(3,3)= -2*B(3,3)*voltage(3) + voltage(1)*(G(3,1)*sin(angle(3) - angle(1)) - B(3,1)*cos(angle(3) - angle(1))) + voltage(2)*(G(3,2)*sin(angle(3) - angle(2)) - B(3,2)*cos(angle(3) - angle(2)));

    % ---------Bus Voltages--------%
    for i = 1:length(V)
        V(i) = voltage(i)*exp(sqrt(-1)*angle(i));
    end
    Iinj=Y*V';                   % injected current
    for i = 1:length(V)
        S(i) = V(i)*conj(Iinj(i));
    end

    % -----Mismatch at PQ and PV buses-------%
    Mismatch(1,1)=Psp(2) - real(S(1,2));
    Mismatch(2,1)=Psp(3) - real(S(1,3));
    Mismatch(3,1)=Qsp(3) - imag(S(1,3));

    % -------calculate new delta values for ANG2, ANG3, and MAG3------&
    delta = inv(J)*Mismatch;
    deltaAngle(2) = delta(1);
    deltaAngle(3) = delta(2);
    deltaVoltage(3) = delta(3);

    % -------Calculate Power Flow on the Transmission Lines-------%

    if(CAPFLAG)
        for i = 1:length(V)
            for j = 1:length(V)
                if(i~=j)
                    P{iter}(i,j) = real(V(i)*conj(V(i) - V(j)/Z(i,j)) + V(i)/Zc(i,j));
                    Q{iter}(i,j) = imag(V(i)*conj(V(i) - V(j)/Z(i,j)) + V(i)/Zc(i,j));
                else
                    P{iter}(i,j) = real(S(i));
                    Q{iter}(i,j) = imag(S(i));
                end;
            end;
        end;

    else
        for i = 1:length(V)
            for j = 1:length(V)
                if(i~=j)
                    P{iter}(i,j) = real(V(i)*conj(V(i) - V(j)/Z(i,j)));
                    Q{iter}(i,j) = imag(V(i)*conj(V(i) - V(j)/Z(i,j)));
                else
                    P{iter}(i,j) = real(S(i));
                    Q{iter}(i,j) = imag(S(i));
                end;
            end;
        end;
    end;

	displayResults(P,Q,voltage,iter);


    if max(abs(Mismatch)) > TOL,
        convFlag=1;
    else
        convFlag=0;
    end
    iter = iter + 1;
end

return;


