% ThreeBusPowerFlow is the main file which calls the Gauss Seidel and Newton Raphson methods. 
% Keep all the 5 files in the same  folder.
%
% To execute type "[P Q] = threeBusPowerFlow(method,CAPFLAG); " at the command prompt with the suitable values of method and CAPFLAG as desired
%
% method = 1 means Newton Raphson Method
%        = 2 means Gauss Seidel Method
%
% CAPFLAG = 0 means no shunt capacitance added
%         = 1 means shunt capacitance added
%
% Functions: threeBusPowerFlow ---- Main wrapper code calling both the methods
%            runGaussSeidel    ---- PowerFlow calculation using Gauss Seidel Method
%            runNewtonRaphson  ---- PowerFlow calculation using Newton Raphson Method
%            inputBusData      ---- BusData values like voltage , angle and specified P,Q values entered here
%            displayResults    ---- Displays the formatted results

%-------------------------------------------------------------------------------------------------------------------------------------------------------%

function [P Q]= threeBusPowerFlow(method, CAPFLAG)

% -------- initialize default variables -------- %
voltage = ones(1,3);
Psp = zeros(1,3);
Qsp = zeros(1,3);
angle = zeros(1,3);

% ---------- user specification ------------ %

voltage(2) =1.05; 
Psp(2) =  2.0; 
Psp(3) = -5.0; 
Qsp(3) = -1.0;

switch method
    case 1
        [P Q] = runNewtonRaphson(voltage, angle, Psp, Qsp, CAPFLAG);
    case 2
        [P Q] = runGaussSeidel(voltage, angle, Psp, Qsp, CAPFLAG);
end;



%---------displaying inter-bus power flows----------%
        
fprintf('\n %s','Flows on Line 1-2')
fprintf('\n %s \n', ' P12       Q12        P21        Q21 ')
fprintf(' %7.4f   %7.4f   %7.4f   %7.4f \n', P(1,2), Q(1,2) ,P(2,1), Q(2,1))

fprintf('\n %s','Flows on Line 1-3')
fprintf('\n %s \n', ' P13       Q13        P31        Q31 ')
fprintf(' %7.4f   %7.4f   %7.4f   %7.4f \n', P(1,3), Q(1,3) ,P(3,1), Q(3,1))

fprintf('\n %s','Flows on Line 2-3')
fprintf('\n %s \n', ' P23       Q23        P32        Q32 ')
fprintf(' %7.4f   %7.4f   %7.4f   %7.4f \n', P(2,3), Q(2,3) ,P(3,2), Q(3,2))

fprintf('\n %s','Net P,Q at Buses')
fprintf('\n %s \n', '  P1       Q1        P2        Q2       P3       Q3  ')
fprintf(' %7.4f   %7.4f   %7.4f   %7.4f   %7.4f   %7.4f \n', P(1,1), Q(1,1) ,P(2,2), Q(2,2), P(3,3), Q(3,3))


return